package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaHouseSales;
import com.huiju.estateagents.service.ITaHouseSalesService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 房源与销售批次表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/")
public class TaHouseSalesController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHouseSalesController.class);

    @Autowired
    public ITaHouseSalesService iTaHouseSalesService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taHouseSales",method= RequestMethod.GET)
    public ResponseBean taHouseSalesList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaHouseSales> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaHouseSales> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaHouseSales> result = iTaHouseSalesService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHouseSalesList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taHouseSales 实体对象
     * @return
     */
    @RequestMapping(value="/taHouseSales",method= RequestMethod.POST)
    public ResponseBean taHouseSalesAdd(@RequestBody TaHouseSales taHouseSales){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaHouseSalesService.save(taHouseSales)){
                responseBean.addSuccess(taHouseSales);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHouseSalesAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taHouseSales/{id}", method= RequestMethod.DELETE)
    public ResponseBean taHouseSalesDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaHouseSalesService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHouseSalesDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHouseSales 实体对象
     * @return
     */
    @RequestMapping(value="/taHouseSales/{id}",method= RequestMethod.PUT)
    public ResponseBean taHouseSalesUpdate(@PathVariable Integer id,
                                           @RequestBody TaHouseSales taHouseSales){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaHouseSalesService.updateById(taHouseSales)){
                responseBean.addSuccess(taHouseSales);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHouseSalesUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taHouseSales/{id}",method= RequestMethod.GET)
    public ResponseBean taHouseSalesGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaHouseSalesService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHouseSalesDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
