package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaPreselectionRecord;
import com.huiju.estateagents.service.ITaPreselectionRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 预选记录表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/")
public class TaPreselectionRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPreselectionRecordController.class);

    @Autowired
    public ITaPreselectionRecordService iTaPreselectionRecordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPreselectionRecord",method= RequestMethod.GET)
    public ResponseBean taPreselectionRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaPreselectionRecord> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPreselectionRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPreselectionRecord> result = iTaPreselectionRecordService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPreselectionRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taPreselectionRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taPreselectionRecord",method= RequestMethod.POST)
    public ResponseBean taPreselectionRecordAdd(@RequestBody TaPreselectionRecord taPreselectionRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaPreselectionRecordService.save(taPreselectionRecord)){
                responseBean.addSuccess(taPreselectionRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPreselectionRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taPreselectionRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean taPreselectionRecordDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaPreselectionRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPreselectionRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPreselectionRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taPreselectionRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean taPreselectionRecordUpdate(@PathVariable Integer id,
                                                   @RequestBody TaPreselectionRecord taPreselectionRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaPreselectionRecordService.updateById(taPreselectionRecord)){
                responseBean.addSuccess(taPreselectionRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPreselectionRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPreselectionRecord/{id}",method= RequestMethod.GET)
    public ResponseBean taPreselectionRecordGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaPreselectionRecordService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPreselectionRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
