package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaSalesBatch;
import com.huiju.estateagents.service.ITaSalesBatchService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 销售批次表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/")
public class TaSalesBatchController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSalesBatchController.class);

    @Autowired
    public ITaSalesBatchService iTaSalesBatchService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taSalesBatch",method= RequestMethod.GET)
    public ResponseBean taSalesBatchList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaSalesBatch> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaSalesBatch> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaSalesBatch> result = iTaSalesBatchService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taSalesBatch 实体对象
     * @return
     */
    @RequestMapping(value="/taSalesBatch",method= RequestMethod.POST)
    public ResponseBean taSalesBatchAdd(@RequestBody TaSalesBatch taSalesBatch){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaSalesBatchService.save(taSalesBatch)){
                responseBean.addSuccess(taSalesBatch);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taSalesBatch/{id}", method= RequestMethod.DELETE)
    public ResponseBean taSalesBatchDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaSalesBatchService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taSalesBatch 实体对象
     * @return
     */
    @RequestMapping(value="/taSalesBatch/{id}",method= RequestMethod.PUT)
    public ResponseBean taSalesBatchUpdate(@PathVariable Integer id,
                                           @RequestBody TaSalesBatch taSalesBatch){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaSalesBatchService.updateById(taSalesBatch)){
                responseBean.addSuccess(taSalesBatch);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taSalesBatch/{id}",method= RequestMethod.GET)
    public ResponseBean taSalesBatchGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaSalesBatchService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSalesBatchDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
